@@ -108,7 +108,7 @@ assign(
               type = "Table Cell",
               backgroundColor="transparent",
               padding = "0.0382in",
-              verticalAlign = "auto",
+              verticalAlign = "automatic",
               padding = "0.0382in",
               leftBorder = "none",
               rightBorder = "none",
@@ -119,7 +119,7 @@ assign(
               type = "Table Cell",
               backgroundColor="#FFFFFF",
               padding = "0.0382in",
-              verticalAlign = "auto",
+              verticalAlign = "automatic",
               leftBorder = "none",
               rightBorder = "none",
               topBorder = "none",
