@@ -1,6 +1,6 @@
 # Max wants this to be 'stylified'
 odfFigureCaption <- function(caption, numformat='1', numlettersync=FALSE,
-      formula='Illustration+1')
+      formula='Illustration+1', label='Illustration')
 {
    # sanity check numformat argument
    if (!any(numformat == c('A', 'a', 'I', 'i', '1')))
@@ -14,12 +14,12 @@ odfFigureCaption <- function(caption, numformat='1', numlettersync=FALSE,
    # we are ready to generate the XML for the figure/illustration
    .odfEnv$fig.caption <- list(caption=caption, numformat=numformat,
                                numlettersync=numlettersync, formula=formula,
-                               refname=refname)
-   invisible(NULL)
+                               refname=refname, label=label)
+   invisible(refname)
 }
 
 
-xRef <- function(name, type = "number", initial = NULL)
+xRef <- function(name, type = "value", initial = NULL)
   {
 
     ## todo: check type values
