@@ -11,7 +11,14 @@ function(
    if(!is.null(colnames)) colnames <- odfTranslate(colnames, toR = FALSE)  
    xMat <- if(horizontal) as.matrix(t(x)) else as.matrix(x)
    colTypes <- apply(xMat, 2, odfDataType)
-   xChar <- format(xMat, digits = digits, ...)
+
+   theDots <- list(...)
+   if(!any(names(theDots) == "justify")) theDots$justify <- "none"
+   if(!any(names(theDots) == "trim")) theDots$trim <- TRUE
+   
+   args <- list(x = xMat, digits = digits)
+   args <- c(args, theDots)
+   xChar <- do.call("format", args)
 
    if(is.null(styles))    styles <- tableStyles(xChar, useRowNames = FALSE, colnames)
 
